# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/wifi_util.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/wifi_util.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!spacex/api/device/wifi_util.proto\x12\x11SpaceX.API.Device\"\xf2\x01\n\x17InflatedBasicServiceSet\x12\x14\n\x05\x62ssid\x18\x01 \x01(\tR\x05\x62ssid\x12\x12\n\x04ssid\x18\x02 \x01(\tR\x04ssid\x12\x17\n\x07mac_lan\x18\x03 \x01(\tR\x06macLan\x12\x1d\n\niface_name\x18\x04 \x01(\tR\tifaceName\x12;\n\niface_type\x18\x05 \x01(\x0e\x32\x1c.SpaceX.API.Device.IfaceTypeR\tifaceType\x12\x18\n\x07\x63hannel\x18\x06 \x01(\rR\x07\x63hannel\x12\x1e\n\npreference\x18\x07 \x01(\rR\npreference\"\xbf\x01\n\tDhcpLease\x12\x1d\n\nip_address\x18\x01 \x01(\tR\tipAddress\x12\x1f\n\x0bmac_address\x18\x02 \x01(\tR\nmacAddress\x12\x1a\n\x08hostname\x18\x03 \x01(\tR\x08hostname\x12!\n\x0c\x65xpires_time\x18\x04 \x01(\tR\x0b\x65xpiresTime\x12\x16\n\x06\x61\x63tive\x18\x05 \x01(\x08R\x06\x61\x63tive\x12\x1b\n\tclient_id\x18\x06 \x01(\rR\x08\x63lientId\"r\n\nDhcpServer\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12\x16\n\x06subnet\x18\x02 \x01(\tR\x06subnet\x12\x34\n\x06leases\x18\x03 \x03(\x0b\x32\x1c.SpaceX.API.Device.DhcpLeaseR\x06leases\"\xe8\x04\n\x0eRadiusStatsMap\x12U\n\x0cradius_stats\x18\x01 \x03(\x0b\x32\x32.SpaceX.API.Device.RadiusStatsMap.RadiusStatsEntryR\x0bradiusStats\x1am\n\x10RadiusStatsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32-.SpaceX.API.Device.RadiusStatsMap.RadiusStatsR\x05value:\x02\x38\x01\x1a\x8f\x03\n\x0bRadiusStats\x12\x1d\n\niface_name\x18\x01 \x01(\tR\tifaceName\x12#\n\rtimeout_count\x18\x02 \x01(\rR\x0ctimeoutCount\x12\x30\n\x14\x61\x63\x63\x65ss_request_count\x18\x03 \x01(\rR\x12\x61\x63\x63\x65ssRequestCount\x12.\n\x13\x61\x63\x63\x65ss_accept_count\x18\x04 \x01(\rR\x11\x61\x63\x63\x65ssAcceptCount\x12.\n\x13\x61\x63\x63\x65ss_reject_count\x18\x05 \x01(\rR\x11\x61\x63\x63\x65ssRejectCount\x12\x34\n\x16\x61\x63\x63\x65ss_challenge_count\x18\x06 \x01(\rR\x14\x61\x63\x63\x65ssChallengeCount\x12\x38\n\x18\x61\x63\x63ounting_request_count\x18\x07 \x01(\rR\x16\x61\x63\x63ountingRequestCount\x12:\n\x19\x61\x63\x63ounting_response_count\x18\x08 \x01(\rR\x17\x61\x63\x63ountingResponseCount\"\xcd\x02\n\x08PoeStats\x12\x38\n\tpoe_state\x18\x01 \x01(\x0e\x32\x1b.SpaceX.API.Device.PoeStateR\x08poeState\x12\x1b\n\tpoe_power\x18\x02 \x01(\x02R\x08poePower\x12=\n\x1bpoe_faults_fast_overcurrent\x18\x03 \x01(\rR\x18poeFaultsFastOvercurrent\x12=\n\x1bpoe_faults_slow_overcurrent\x18\x04 \x01(\rR\x18poeFaultsSlowOvercurrent\x12\x34\n\x16poe_faults_overvoltage\x18\x05 \x01(\rR\x14poeFaultsOvervoltage\x12\x36\n\x17poe_faults_undervoltage\x18\x06 \x01(\rR\x15poeFaultsUndervoltage\"\xe3\x01\n\x17WifiSoftwareUpdateStats\x12@\n\x05state\x18\x01 \x01(\x0e\x32*.SpaceX.API.Device.WifiSoftwareUpdateStateR\x05state\x12<\n\x1asoftware_download_progress\x18\x02 \x01(\x02R\x18softwareDownloadProgress\x12H\n!seconds_since_get_target_versions\x18\x03 \x01(\x02R\x1dsecondsSinceGetTargetVersions*\x84\x01\n\tIfaceType\x12\x16\n\x12IFACE_TYPE_UNKNOWN\x10\x00\x12\x12\n\x0eIFACE_TYPE_ETH\x10\x01\x12\x16\n\x12IFACE_TYPE_RF_2GHZ\x10\x02\x12\x16\n\x12IFACE_TYPE_RF_5GHZ\x10\x05\x12\x1b\n\x17IFACE_TYPE_RF_5GHZ_HIGH\x10\x06*\x98\x01\n\x0cTxPowerLevel\x12\x16\n\x12TX_POWER_LEVEL_100\x10\x00\x12\x15\n\x11TX_POWER_LEVEL_80\x10\x01\x12\x15\n\x11TX_POWER_LEVEL_50\x10\x02\x12\x15\n\x11TX_POWER_LEVEL_25\x10\x03\x12\x15\n\x11TX_POWER_LEVEL_12\x10\x04\x12\x14\n\x10TX_POWER_LEVEL_6\x10\x05*\xa7\x01\n\x08PoeState\x12\x16\n\x12POE_STATE_DISABLED\x10\x00\x12\x19\n\x15POE_STATE_NEGOTIATING\x10\x01\x12\x17\n\x13POE_STATE_ON_RAMPUP\x10\x02\x12\x10\n\x0cPOE_STATE_ON\x10\x03\x12!\n\x1dPOE_STATE_WATER_DETECT_RAMPUP\x10\x04\x12\x1a\n\x16POE_STATE_WATER_DETECT\x10\x05*\x9d\x01\n\x08PoeFault\x12\x1e\n\x1aPOE_FAULT_FAST_OVERCURRENT\x10\x00\x12\x1e\n\x1aPOE_FAULT_SLOW_OVERCURRENT\x10\x01\x12\x1a\n\x16POE_FAULT_UNDERCURRENT\x10\x02\x12\x19\n\x15POE_FAULT_OVERVOLTAGE\x10\x03\x12\x1a\n\x16POE_FAULT_UNDERVOLTAGE\x10\x04*\x84\x02\n\x08WifiMode\x12\x15\n\x11WIFI_MODE_DEFAULT\x10\x00\x12\n\n\x06\x41_ONLY\x10\x01\x12\n\n\x06\x42_ONLY\x10\x02\x12\n\n\x06G_ONLY\x10\x03\x12\n\n\x06N_ONLY\x10\x04\x12\r\n\tB_G_MIXED\x10\x05\x12\r\n\tA_N_MIXED\x10\x06\x12\r\n\tG_N_MIXED\x10\x07\x12\x0f\n\x0b\x42_G_N_MIXED\x10\x08\x12\x11\n\rA_AN_AC_MIXED\x10\t\x12\x0f\n\x0b\x41N_AC_MIXED\x10\n\x12\x12\n\x0e\x42_G_N_AX_MIXED\x10\x0b\x12\x14\n\x10\x41_AN_AC_AX_MIXED\x10\x0c\x12\x10\n\x0c\x41_N_AC_MIXED\x10\r\x12\x13\n\x0f\x41_N_AC_AX_MIXED\x10\x0e*U\n\x0cWifiSecurity\x12\x19\n\x15WIFI_SECURITY_UNKNOWN\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\x08\n\x04WPA2\x10\x02\x12\x08\n\x04WPA3\x10\x03\x12\x0c\n\x08WPA2WPA3\x10\x04*/\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01\x12\x07\n\x03TLS\x10\x02\x12\x08\n\x04\x44TLS\x10\x03*\xf2\x02\n\x17WifiSoftwareUpdateState\x12\x0b\n\x07NOT_RUN\x10\x00\x12\x1a\n\x16GETTING_TARGET_VERSION\x10\x01\x12\x1c\n\x18\x44OWNLOADING_UPDATE_IMAGE\x10\x02\x12\x0c\n\x08\x46LASHING\x10\x03\x12\x16\n\x12NO_UPDATE_REQUIRED\x10\x04\x12\x12\n\x0eREBOOT_PENDING\x10\x05\x12!\n\x1dGETTING_TARGET_VERSION_FAILED\x10\x06\x12$\n GETTING_TARGET_VERSION_EXHAUSTED\x10\x07\x12\x15\n\x11NO_VALID_ARTIFACT\x10\x08\x12\x14\n\x10ILLEGAL_ARTIFACT\x10\t\x12#\n\x1f\x44OWNLOADING_UPDATE_IMAGE_FAILED\x10\n\x12&\n\"DOWNLOADING_UPDATE_IMAGE_EXHAUSTED\x10\x0b\x12\x13\n\x0f\x46LASHING_FAILED\x10\x0c\x42\xd7\x01\n\x15\x63om.SpaceX.API.DeviceB\rWifiUtilProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.wifi_util_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\rWifiUtilProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_RADIUSSTATSMAP_RADIUSSTATSENTRY']._loaded_options = None
  _globals['_RADIUSSTATSMAP_RADIUSSTATSENTRY']._serialized_options = b'8\001'
  _globals['_IFACETYPE']._serialized_start=1797
  _globals['_IFACETYPE']._serialized_end=1929
  _globals['_TXPOWERLEVEL']._serialized_start=1932
  _globals['_TXPOWERLEVEL']._serialized_end=2084
  _globals['_POESTATE']._serialized_start=2087
  _globals['_POESTATE']._serialized_end=2254
  _globals['_POEFAULT']._serialized_start=2257
  _globals['_POEFAULT']._serialized_end=2414
  _globals['_WIFIMODE']._serialized_start=2417
  _globals['_WIFIMODE']._serialized_end=2677
  _globals['_WIFISECURITY']._serialized_start=2679
  _globals['_WIFISECURITY']._serialized_end=2764
  _globals['_PROTOCOL']._serialized_start=2766
  _globals['_PROTOCOL']._serialized_end=2813
  _globals['_WIFISOFTWAREUPDATESTATE']._serialized_start=2816
  _globals['_WIFISOFTWAREUPDATESTATE']._serialized_end=3186
  _globals['_INFLATEDBASICSERVICESET']._serialized_start=57
  _globals['_INFLATEDBASICSERVICESET']._serialized_end=299
  _globals['_DHCPLEASE']._serialized_start=302
  _globals['_DHCPLEASE']._serialized_end=493
  _globals['_DHCPSERVER']._serialized_start=495
  _globals['_DHCPSERVER']._serialized_end=609
  _globals['_RADIUSSTATSMAP']._serialized_start=612
  _globals['_RADIUSSTATSMAP']._serialized_end=1228
  _globals['_RADIUSSTATSMAP_RADIUSSTATSENTRY']._serialized_start=717
  _globals['_RADIUSSTATSMAP_RADIUSSTATSENTRY']._serialized_end=826
  _globals['_RADIUSSTATSMAP_RADIUSSTATS']._serialized_start=829
  _globals['_RADIUSSTATSMAP_RADIUSSTATS']._serialized_end=1228
  _globals['_POESTATS']._serialized_start=1231
  _globals['_POESTATS']._serialized_end=1564
  _globals['_WIFISOFTWAREUPDATESTATS']._serialized_start=1567
  _globals['_WIFISOFTWAREUPDATESTATS']._serialized_end=1794
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UnlockChallenge(_message.Message):
    __slots__ = ("device_id", "nonce", "sign_spki", "grant_keydata", "service_keydata", "authority_grants")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    NONCE_FIELD_NUMBER: _ClassVar[int]
    SIGN_SPKI_FIELD_NUMBER: _ClassVar[int]
    GRANT_KEYDATA_FIELD_NUMBER: _ClassVar[int]
    SERVICE_KEYDATA_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_GRANTS_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    nonce: bytes
    sign_spki: bytes
    grant_keydata: str
    service_keydata: str
    authority_grants: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, device_id: _Optional[str] = ..., nonce: _Optional[bytes] = ..., sign_spki: _Optional[bytes] = ..., grant_keydata: _Optional[str] = ..., service_keydata: _Optional[str] = ..., authority_grants: _Optional[_Iterable[str]] = ...) -> None: ...

class StartUnlockRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class StartUnlockResponse(_message.Message):
    __slots__ = ("device_id", "nonce", "sign_spki")
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    NONCE_FIELD_NUMBER: _ClassVar[int]
    SIGN_SPKI_FIELD_NUMBER: _ClassVar[int]
    device_id: str
    nonce: bytes
    sign_spki: bytes
    def __init__(self, device_id: _Optional[str] = ..., nonce: _Optional[bytes] = ..., sign_spki: _Optional[bytes] = ...) -> None: ...

class FinishUnlockRequest(_message.Message):
    __slots__ = ("challenge", "signature")
    CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    challenge: bytes
    signature: bytes
    def __init__(self, challenge: _Optional[bytes] = ..., signature: _Optional[bytes] = ...) -> None: ...

class FinishUnlockResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: int
    def __init__(self, status: _Optional[int] = ...) -> None: ...



from spacex.api.device import command_pb2 as _command_pb2
from spacex.api.device import common_pb2 as _common_pb2
from spacex.api.device import wifi_util_pb2 as _wifi_util_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MeshAuth(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MESH_AUTH_UNKNOWN: _ClassVar[MeshAuth]
    MESH_AUTH_NEW: _ClassVar[MeshAuth]
    MESH_AUTH_TRUSTED: _ClassVar[MeshAuth]
    MESH_AUTH_UNTRUSTED: _ClassVar[MeshAuth]

class CakeAckFilter(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NO_ACK_FILTER: _ClassVar[CakeAckFilter]
    ACK_FILTER: _ClassVar[CakeAckFilter]
    ACK_FILTER_AGGRESSIVE: _ClassVar[CakeAckFilter]

class CakePriorityQueueParameter(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DIFFSERV3: _ClassVar[CakePriorityQueueParameter]
    DIFFSERV4: _ClassVar[CakePriorityQueueParameter]
    PRECEDENCE: _ClassVar[CakePriorityQueueParameter]
    BEST_EFFORT: _ClassVar[CakePriorityQueueParameter]
MESH_AUTH_UNKNOWN: MeshAuth
MESH_AUTH_NEW: MeshAuth
MESH_AUTH_TRUSTED: MeshAuth
MESH_AUTH_UNTRUSTED: MeshAuth
NO_ACK_FILTER: CakeAckFilter
ACK_FILTER: CakeAckFilter
ACK_FILTER_AGGRESSIVE: CakeAckFilter
DIFFSERV3: CakePriorityQueueParameter
DIFFSERV4: CakePriorityQueueParameter
PRECEDENCE: CakePriorityQueueParameter
BEST_EFFORT: CakePriorityQueueParameter

class MeshConfig(_message.Message):
    __slots__ = ("display_name", "apply_display_name", "auth", "apply_auth", "last_connected", "incarnation", "hardware_version", "supports_5ghz_high")
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    APPLY_AUTH_FIELD_NUMBER: _ClassVar[int]
    LAST_CONNECTED_FIELD_NUMBER: _ClassVar[int]
    INCARNATION_FIELD_NUMBER: _ClassVar[int]
    HARDWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    SUPPORTS_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    apply_display_name: bool
    auth: MeshAuth
    apply_auth: bool
    last_connected: int
    incarnation: int
    hardware_version: str
    supports_5ghz_high: bool
    def __init__(self, display_name: _Optional[str] = ..., apply_display_name: bool = ..., auth: _Optional[_Union[MeshAuth, str]] = ..., apply_auth: bool = ..., last_connected: _Optional[int] = ..., incarnation: _Optional[int] = ..., hardware_version: _Optional[str] = ..., supports_5ghz_high: bool = ...) -> None: ...

class WifiConfig(_message.Message):
    __slots__ = ("country_code", "apply_country_code", "pin_country_code", "apply_pin_country_code", "custom_power_table", "apply_custom_power_table", "setup_complete", "apply_setup_complete", "version", "mac_wan", "mac_lan", "channel_2ghz", "apply_channel_2ghz", "channel_5ghz", "apply_channel_5ghz", "channel_5ghz_high", "apply_channel_5ghz_high", "mesh_configs", "mesh_configs_updates", "apply_mesh_configs", "dynamic_keys", "apply_dynamic_keys", "is_repeater", "apply_is_repeater", "ap_mode", "apply_ap_mode", "is_aviation", "apply_is_aviation", "boot_count", "boot", "nameservers", "apply_nameservers", "secure_dns", "apply_secure_dns", "bypass_mode", "apply_bypass_mode", "dfs_enabled", "apply_dfs_enabled", "disable_mesh_onboarding", "apply_disable_mesh_onboarding", "networks", "apply_networks", "incarnation", "wireless_mode_2ghz", "apply_wireless_mode_2ghz", "wireless_mode_5ghz", "apply_wireless_mode_5ghz", "wireless_mode_5ghz_high", "apply_wireless_mode_5ghz_high", "ht_bandwidth_2ghz", "apply_ht_bandwidth_2ghz", "ht_bandwidth_5ghz", "apply_ht_bandwidth_5ghz", "ht_bandwidth_5ghz_high", "apply_ht_bandwidth_5ghz_high", "vht_bandwidth", "apply_vht_bandwidth", "vht_bandwidth_5ghz_high", "apply_vht_bandwidth_5ghz_high", "use_public_services", "apply_use_public_services", "disable_automated_speedtests", "apply_disable_automated_speedtests", "enable_umbilical_vlan", "apply_enable_umbilical_vlan", "client_names", "apply_client_names", "outdoor_mode", "apply_outdoor_mode", "disable_2ghz", "apply_disable_2ghz", "disable_5ghz", "apply_disable_5ghz", "disable_5ghz_high", "apply_disable_5ghz_high", "disable_x_mesh_backhaul", "apply_disable_x_mesh_backhaul", "golden_bssid", "apply_golden_bssid", "golden_iface_type", "apply_golden_iface_type", "tx_power_level_2ghz", "apply_tx_power_level_2ghz", "tx_power_level_5ghz", "apply_tx_power_level_5ghz", "tx_power_level_5ghz_high", "apply_tx_power_level_5ghz_high", "disable_pending_update_reboot", "apply_disable_pending_update_reboot", "client_configs", "apply_client_configs", "disable_set_wifi_config_from_controller", "apply_disable_set_wifi_config_from_controller", "client_key", "apply_client_key", "wan_no_traffic_control", "wan_ack_suppression", "wan_cake_rate_limit", "apply_wan_traffic_control", "wan_host_dscp_mark", "apply_wan_host_dscp_mark", "debug_pop_pings", "apply_debug_pop_pings", "client_tester", "apply_client_tester", "tag")
    class Security(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[WifiConfig.Security]
        WPA2: _ClassVar[WifiConfig.Security]
        WPA3: _ClassVar[WifiConfig.Security]
        WPA2WPA3: _ClassVar[WifiConfig.Security]
    UNKNOWN: WifiConfig.Security
    WPA2: WifiConfig.Security
    WPA3: WifiConfig.Security
    WPA2WPA3: WifiConfig.Security
    class Band(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        RF_UNKNOWN: _ClassVar[WifiConfig.Band]
        RF_2GHZ: _ClassVar[WifiConfig.Band]
        RF_5GHZ: _ClassVar[WifiConfig.Band]
        RF_5GHZ_HIGH: _ClassVar[WifiConfig.Band]
    RF_UNKNOWN: WifiConfig.Band
    RF_2GHZ: WifiConfig.Band
    RF_5GHZ: WifiConfig.Band
    RF_5GHZ_HIGH: WifiConfig.Band
    class WirelessMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        WIRELESS_MODE_DEFAULT: _ClassVar[WifiConfig.WirelessMode]
        A_ONLY: _ClassVar[WifiConfig.WirelessMode]
        B_ONLY: _ClassVar[WifiConfig.WirelessMode]
        G_ONLY: _ClassVar[WifiConfig.WirelessMode]
        N_ONLY: _ClassVar[WifiConfig.WirelessMode]
        B_G_MIXED: _ClassVar[WifiConfig.WirelessMode]
        A_N_MIXED: _ClassVar[WifiConfig.WirelessMode]
        G_N_MIXED: _ClassVar[WifiConfig.WirelessMode]
        B_G_N_MIXED: _ClassVar[WifiConfig.WirelessMode]
        A_AN_AC_MIXED: _ClassVar[WifiConfig.WirelessMode]
        AN_AC_MIXED: _ClassVar[WifiConfig.WirelessMode]
        B_G_N_AX_MIXED: _ClassVar[WifiConfig.WirelessMode]
        A_AN_AC_AX_MIXED: _ClassVar[WifiConfig.WirelessMode]
    WIRELESS_MODE_DEFAULT: WifiConfig.WirelessMode
    A_ONLY: WifiConfig.WirelessMode
    B_ONLY: WifiConfig.WirelessMode
    G_ONLY: WifiConfig.WirelessMode
    N_ONLY: WifiConfig.WirelessMode
    B_G_MIXED: WifiConfig.WirelessMode
    A_N_MIXED: WifiConfig.WirelessMode
    G_N_MIXED: WifiConfig.WirelessMode
    B_G_N_MIXED: WifiConfig.WirelessMode
    A_AN_AC_MIXED: WifiConfig.WirelessMode
    AN_AC_MIXED: WifiConfig.WirelessMode
    B_G_N_AX_MIXED: WifiConfig.WirelessMode
    A_AN_AC_AX_MIXED: WifiConfig.WirelessMode
    class HTBandwidth(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        HT_BANDWIDTH_DEFAULT: _ClassVar[WifiConfig.HTBandwidth]
        HT_BANDWIDTH_20_MHZ: _ClassVar[WifiConfig.HTBandwidth]
        HT_BANDWIDTH_20_OR_40_MHZ: _ClassVar[WifiConfig.HTBandwidth]
    HT_BANDWIDTH_DEFAULT: WifiConfig.HTBandwidth
    HT_BANDWIDTH_20_MHZ: WifiConfig.HTBandwidth
    HT_BANDWIDTH_20_OR_40_MHZ: WifiConfig.HTBandwidth
    class VHTBandwidth(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VHT_BANDWIDTH_DEFAULT: _ClassVar[WifiConfig.VHTBandwidth]
        VHT_BANDWIDTH_DISABLED: _ClassVar[WifiConfig.VHTBandwidth]
        VHT_BANDWIDTH_80_MHZ: _ClassVar[WifiConfig.VHTBandwidth]
        VHT_BANDWIDTH_160_MHZ: _ClassVar[WifiConfig.VHTBandwidth]
        VHT_BANDWIDTH_80_PLUS_80_MHZ: _ClassVar[WifiConfig.VHTBandwidth]
    VHT_BANDWIDTH_DEFAULT: WifiConfig.VHTBandwidth
    VHT_BANDWIDTH_DISABLED: WifiConfig.VHTBandwidth
    VHT_BANDWIDTH_80_MHZ: WifiConfig.VHTBandwidth
    VHT_BANDWIDTH_160_MHZ: WifiConfig.VHTBandwidth
    VHT_BANDWIDTH_80_PLUS_80_MHZ: WifiConfig.VHTBandwidth
    class MeshConfigsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: MeshConfig
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[MeshConfig, _Mapping]] = ...) -> None: ...
    class MeshConfigsUpdatesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: MeshConfig
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[MeshConfig, _Mapping]] = ...) -> None: ...
    class BasicServiceSet(_message.Message):
        __slots__ = ("bssid", "ssid", "auth_open", "auth_wpa2", "auth_wpa3", "auth_wpa2_wpa3", "auth_radius", "band", "iface_name", "disable", "hidden")
        BSSID_FIELD_NUMBER: _ClassVar[int]
        SSID_FIELD_NUMBER: _ClassVar[int]
        AUTH_OPEN_FIELD_NUMBER: _ClassVar[int]
        AUTH_WPA2_FIELD_NUMBER: _ClassVar[int]
        AUTH_WPA3_FIELD_NUMBER: _ClassVar[int]
        AUTH_WPA2_WPA3_FIELD_NUMBER: _ClassVar[int]
        AUTH_RADIUS_FIELD_NUMBER: _ClassVar[int]
        BAND_FIELD_NUMBER: _ClassVar[int]
        IFACE_NAME_FIELD_NUMBER: _ClassVar[int]
        DISABLE_FIELD_NUMBER: _ClassVar[int]
        HIDDEN_FIELD_NUMBER: _ClassVar[int]
        bssid: str
        ssid: str
        auth_open: AuthOpen
        auth_wpa2: AuthWpa2
        auth_wpa3: AuthWpa3
        auth_wpa2_wpa3: AuthWpa2Wpa3
        auth_radius: AuthRadius
        band: WifiConfig.Band
        iface_name: str
        disable: bool
        hidden: bool
        def __init__(self, bssid: _Optional[str] = ..., ssid: _Optional[str] = ..., auth_open: _Optional[_Union[AuthOpen, _Mapping]] = ..., auth_wpa2: _Optional[_Union[AuthWpa2, _Mapping]] = ..., auth_wpa3: _Optional[_Union[AuthWpa3, _Mapping]] = ..., auth_wpa2_wpa3: _Optional[_Union[AuthWpa2Wpa3, _Mapping]] = ..., auth_radius: _Optional[_Union[AuthRadius, _Mapping]] = ..., band: _Optional[_Union[WifiConfig.Band, str]] = ..., iface_name: _Optional[str] = ..., disable: bool = ..., hidden: bool = ...) -> None: ...
    class Network(_message.Message):
        __slots__ = ("ipv4", "dhcpv4_start", "dhcp_disabled", "dhcpv4_lease_duration_s", "domain", "basic_service_sets", "client_isolation", "guest", "landing", "landing_page_v2", "internal", "vlan")
        IPV4_FIELD_NUMBER: _ClassVar[int]
        DHCPV4_START_FIELD_NUMBER: _ClassVar[int]
        DHCP_DISABLED_FIELD_NUMBER: _ClassVar[int]
        DHCPV4_LEASE_DURATION_S_FIELD_NUMBER: _ClassVar[int]
        DOMAIN_FIELD_NUMBER: _ClassVar[int]
        BASIC_SERVICE_SETS_FIELD_NUMBER: _ClassVar[int]
        CLIENT_ISOLATION_FIELD_NUMBER: _ClassVar[int]
        GUEST_FIELD_NUMBER: _ClassVar[int]
        LANDING_FIELD_NUMBER: _ClassVar[int]
        LANDING_PAGE_V2_FIELD_NUMBER: _ClassVar[int]
        INTERNAL_FIELD_NUMBER: _ClassVar[int]
        VLAN_FIELD_NUMBER: _ClassVar[int]
        ipv4: str
        dhcpv4_start: int
        dhcp_disabled: bool
        dhcpv4_lease_duration_s: int
        domain: str
        basic_service_sets: _containers.RepeatedCompositeFieldContainer[WifiConfig.BasicServiceSet]
        client_isolation: bool
        guest: bool
        landing: str
        landing_page_v2: bool
        internal: bool
        vlan: int
        def __init__(self, ipv4: _Optional[str] = ..., dhcpv4_start: _Optional[int] = ..., dhcp_disabled: bool = ..., dhcpv4_lease_duration_s: _Optional[int] = ..., domain: _Optional[str] = ..., basic_service_sets: _Optional[_Iterable[_Union[WifiConfig.BasicServiceSet, _Mapping]]] = ..., client_isolation: bool = ..., guest: bool = ..., landing: _Optional[str] = ..., landing_page_v2: bool = ..., internal: bool = ..., vlan: _Optional[int] = ...) -> None: ...
    COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    PIN_COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_PIN_COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_POWER_TABLE_FIELD_NUMBER: _ClassVar[int]
    APPLY_CUSTOM_POWER_TABLE_FIELD_NUMBER: _ClassVar[int]
    SETUP_COMPLETE_FIELD_NUMBER: _ClassVar[int]
    APPLY_SETUP_COMPLETE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    MAC_WAN_FIELD_NUMBER: _ClassVar[int]
    MAC_LAN_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_2GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_CHANNEL_2GHZ_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_5GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_CHANNEL_5GHZ_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    APPLY_CHANNEL_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    MESH_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    MESH_CONFIGS_UPDATES_FIELD_NUMBER: _ClassVar[int]
    APPLY_MESH_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    APPLY_DYNAMIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    IS_REPEATER_FIELD_NUMBER: _ClassVar[int]
    APPLY_IS_REPEATER_FIELD_NUMBER: _ClassVar[int]
    AP_MODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_AP_MODE_FIELD_NUMBER: _ClassVar[int]
    IS_AVIATION_FIELD_NUMBER: _ClassVar[int]
    APPLY_IS_AVIATION_FIELD_NUMBER: _ClassVar[int]
    BOOT_COUNT_FIELD_NUMBER: _ClassVar[int]
    BOOT_FIELD_NUMBER: _ClassVar[int]
    NAMESERVERS_FIELD_NUMBER: _ClassVar[int]
    APPLY_NAMESERVERS_FIELD_NUMBER: _ClassVar[int]
    SECURE_DNS_FIELD_NUMBER: _ClassVar[int]
    APPLY_SECURE_DNS_FIELD_NUMBER: _ClassVar[int]
    BYPASS_MODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_BYPASS_MODE_FIELD_NUMBER: _ClassVar[int]
    DFS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    APPLY_DFS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    DISABLE_MESH_ONBOARDING_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_MESH_ONBOARDING_FIELD_NUMBER: _ClassVar[int]
    NETWORKS_FIELD_NUMBER: _ClassVar[int]
    APPLY_NETWORKS_FIELD_NUMBER: _ClassVar[int]
    INCARNATION_FIELD_NUMBER: _ClassVar[int]
    WIRELESS_MODE_2GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_WIRELESS_MODE_2GHZ_FIELD_NUMBER: _ClassVar[int]
    WIRELESS_MODE_5GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_WIRELESS_MODE_5GHZ_FIELD_NUMBER: _ClassVar[int]
    WIRELESS_MODE_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    APPLY_WIRELESS_MODE_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    HT_BANDWIDTH_2GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_HT_BANDWIDTH_2GHZ_FIELD_NUMBER: _ClassVar[int]
    HT_BANDWIDTH_5GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_HT_BANDWIDTH_5GHZ_FIELD_NUMBER: _ClassVar[int]
    HT_BANDWIDTH_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    APPLY_HT_BANDWIDTH_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    VHT_BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    APPLY_VHT_BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    VHT_BANDWIDTH_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    APPLY_VHT_BANDWIDTH_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    USE_PUBLIC_SERVICES_FIELD_NUMBER: _ClassVar[int]
    APPLY_USE_PUBLIC_SERVICES_FIELD_NUMBER: _ClassVar[int]
    DISABLE_AUTOMATED_SPEEDTESTS_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_AUTOMATED_SPEEDTESTS_FIELD_NUMBER: _ClassVar[int]
    ENABLE_UMBILICAL_VLAN_FIELD_NUMBER: _ClassVar[int]
    APPLY_ENABLE_UMBILICAL_VLAN_FIELD_NUMBER: _ClassVar[int]
    CLIENT_NAMES_FIELD_NUMBER: _ClassVar[int]
    APPLY_CLIENT_NAMES_FIELD_NUMBER: _ClassVar[int]
    OUTDOOR_MODE_FIELD_NUMBER: _ClassVar[int]
    APPLY_OUTDOOR_MODE_FIELD_NUMBER: _ClassVar[int]
    DISABLE_2GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_2GHZ_FIELD_NUMBER: _ClassVar[int]
    DISABLE_5GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_5GHZ_FIELD_NUMBER: _ClassVar[int]
    DISABLE_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    DISABLE_X_MESH_BACKHAUL_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_X_MESH_BACKHAUL_FIELD_NUMBER: _ClassVar[int]
    GOLDEN_BSSID_FIELD_NUMBER: _ClassVar[int]
    APPLY_GOLDEN_BSSID_FIELD_NUMBER: _ClassVar[int]
    GOLDEN_IFACE_TYPE_FIELD_NUMBER: _ClassVar[int]
    APPLY_GOLDEN_IFACE_TYPE_FIELD_NUMBER: _ClassVar[int]
    TX_POWER_LEVEL_2GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_TX_POWER_LEVEL_2GHZ_FIELD_NUMBER: _ClassVar[int]
    TX_POWER_LEVEL_5GHZ_FIELD_NUMBER: _ClassVar[int]
    APPLY_TX_POWER_LEVEL_5GHZ_FIELD_NUMBER: _ClassVar[int]
    TX_POWER_LEVEL_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    APPLY_TX_POWER_LEVEL_5GHZ_HIGH_FIELD_NUMBER: _ClassVar[int]
    DISABLE_PENDING_UPDATE_REBOOT_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_PENDING_UPDATE_REBOOT_FIELD_NUMBER: _ClassVar[int]
    CLIENT_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    APPLY_CLIENT_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    DISABLE_SET_WIFI_CONFIG_FROM_CONTROLLER_FIELD_NUMBER: _ClassVar[int]
    APPLY_DISABLE_SET_WIFI_CONFIG_FROM_CONTROLLER_FIELD_NUMBER: _ClassVar[int]
    CLIENT_KEY_FIELD_NUMBER: _ClassVar[int]
    APPLY_CLIENT_KEY_FIELD_NUMBER: _ClassVar[int]
    WAN_NO_TRAFFIC_CONTROL_FIELD_NUMBER: _ClassVar[int]
    WAN_ACK_SUPPRESSION_FIELD_NUMBER: _ClassVar[int]
    WAN_CAKE_RATE_LIMIT_FIELD_NUMBER: _ClassVar[int]
    APPLY_WAN_TRAFFIC_CONTROL_FIELD_NUMBER: _ClassVar[int]
    WAN_HOST_DSCP_MARK_FIELD_NUMBER: _ClassVar[int]
    APPLY_WAN_HOST_DSCP_MARK_FIELD_NUMBER: _ClassVar[int]
    DEBUG_POP_PINGS_FIELD_NUMBER: _ClassVar[int]
    APPLY_DEBUG_POP_PINGS_FIELD_NUMBER: _ClassVar[int]
    CLIENT_TESTER_FIELD_NUMBER: _ClassVar[int]
    APPLY_CLIENT_TESTER_FIELD_NUMBER: _ClassVar[int]
    TAG_FIELD_NUMBER: _ClassVar[int]
    country_code: str
    apply_country_code: bool
    pin_country_code: bool
    apply_pin_country_code: bool
    custom_power_table: bool
    apply_custom_power_table: bool
    setup_complete: bool
    apply_setup_complete: bool
    version: int
    mac_wan: str
    mac_lan: str
    channel_2ghz: int
    apply_channel_2ghz: bool
    channel_5ghz: int
    apply_channel_5ghz: bool
    channel_5ghz_high: int
    apply_channel_5ghz_high: bool
    mesh_configs: _containers.MessageMap[str, MeshConfig]
    mesh_configs_updates: _containers.MessageMap[str, MeshConfig]
    apply_mesh_configs: bool
    dynamic_keys: _containers.RepeatedCompositeFieldContainer[_command_pb2.PublicKey]
    apply_dynamic_keys: bool
    is_repeater: bool
    apply_is_repeater: bool
    ap_mode: bool
    apply_ap_mode: bool
    is_aviation: bool
    apply_is_aviation: bool
    boot_count: int
    boot: _common_pb2.BootInfo
    nameservers: _containers.RepeatedScalarFieldContainer[str]
    apply_nameservers: bool
    secure_dns: bool
    apply_secure_dns: bool
    bypass_mode: bool
    apply_bypass_mode: bool
    dfs_enabled: bool
    apply_dfs_enabled: bool
    disable_mesh_onboarding: bool
    apply_disable_mesh_onboarding: bool
    networks: _containers.RepeatedCompositeFieldContainer[WifiConfig.Network]
    apply_networks: bool
    incarnation: int
    wireless_mode_2ghz: WifiConfig.WirelessMode
    apply_wireless_mode_2ghz: bool
    wireless_mode_5ghz: WifiConfig.WirelessMode
    apply_wireless_mode_5ghz: bool
    wireless_mode_5ghz_high: WifiConfig.WirelessMode
    apply_wireless_mode_5ghz_high: bool
    ht_bandwidth_2ghz: WifiConfig.HTBandwidth
    apply_ht_bandwidth_2ghz: bool
    ht_bandwidth_5ghz: WifiConfig.HTBandwidth
    apply_ht_bandwidth_5ghz: bool
    ht_bandwidth_5ghz_high: WifiConfig.HTBandwidth
    apply_ht_bandwidth_5ghz_high: bool
    vht_bandwidth: WifiConfig.VHTBandwidth
    apply_vht_bandwidth: bool
    vht_bandwidth_5ghz_high: WifiConfig.VHTBandwidth
    apply_vht_bandwidth_5ghz_high: bool
    use_public_services: bool
    apply_use_public_services: bool
    disable_automated_speedtests: bool
    apply_disable_automated_speedtests: bool
    enable_umbilical_vlan: bool
    apply_enable_umbilical_vlan: bool
    client_names: _containers.RepeatedCompositeFieldContainer[ClientName]
    apply_client_names: bool
    outdoor_mode: bool
    apply_outdoor_mode: bool
    disable_2ghz: bool
    apply_disable_2ghz: bool
    disable_5ghz: bool
    apply_disable_5ghz: bool
    disable_5ghz_high: bool
    apply_disable_5ghz_high: bool
    disable_x_mesh_backhaul: bool
    apply_disable_x_mesh_backhaul: bool
    golden_bssid: str
    apply_golden_bssid: bool
    golden_iface_type: _wifi_util_pb2.IfaceType
    apply_golden_iface_type: bool
    tx_power_level_2ghz: _wifi_util_pb2.TxPowerLevel
    apply_tx_power_level_2ghz: bool
    tx_power_level_5ghz: _wifi_util_pb2.TxPowerLevel
    apply_tx_power_level_5ghz: bool
    tx_power_level_5ghz_high: _wifi_util_pb2.TxPowerLevel
    apply_tx_power_level_5ghz_high: bool
    disable_pending_update_reboot: bool
    apply_disable_pending_update_reboot: bool
    client_configs: _containers.RepeatedCompositeFieldContainer[ClientConfig]
    apply_client_configs: bool
    disable_set_wifi_config_from_controller: bool
    apply_disable_set_wifi_config_from_controller: bool
    client_key: bytes
    apply_client_key: bool
    wan_no_traffic_control: NoTrafficControl
    wan_ack_suppression: AckSuppression
    wan_cake_rate_limit: CakeRateLimit
    apply_wan_traffic_control: bool
    wan_host_dscp_mark: int
    apply_wan_host_dscp_mark: bool
    debug_pop_pings: bool
    apply_debug_pop_pings: bool
    client_tester: bool
    apply_client_tester: bool
    tag: int
    def __init__(self, country_code: _Optional[str] = ..., apply_country_code: bool = ..., pin_country_code: bool = ..., apply_pin_country_code: bool = ..., custom_power_table: bool = ..., apply_custom_power_table: bool = ..., setup_complete: bool = ..., apply_setup_complete: bool = ..., version: _Optional[int] = ..., mac_wan: _Optional[str] = ..., mac_lan: _Optional[str] = ..., channel_2ghz: _Optional[int] = ..., apply_channel_2ghz: bool = ..., channel_5ghz: _Optional[int] = ..., apply_channel_5ghz: bool = ..., channel_5ghz_high: _Optional[int] = ..., apply_channel_5ghz_high: bool = ..., mesh_configs: _Optional[_Mapping[str, MeshConfig]] = ..., mesh_configs_updates: _Optional[_Mapping[str, MeshConfig]] = ..., apply_mesh_configs: bool = ..., dynamic_keys: _Optional[_Iterable[_Union[_command_pb2.PublicKey, _Mapping]]] = ..., apply_dynamic_keys: bool = ..., is_repeater: bool = ..., apply_is_repeater: bool = ..., ap_mode: bool = ..., apply_ap_mode: bool = ..., is_aviation: bool = ..., apply_is_aviation: bool = ..., boot_count: _Optional[int] = ..., boot: _Optional[_Union[_common_pb2.BootInfo, _Mapping]] = ..., nameservers: _Optional[_Iterable[str]] = ..., apply_nameservers: bool = ..., secure_dns: bool = ..., apply_secure_dns: bool = ..., bypass_mode: bool = ..., apply_bypass_mode: bool = ..., dfs_enabled: bool = ..., apply_dfs_enabled: bool = ..., disable_mesh_onboarding: bool = ..., apply_disable_mesh_onboarding: bool = ..., networks: _Optional[_Iterable[_Union[WifiConfig.Network, _Mapping]]] = ..., apply_networks: bool = ..., incarnation: _Optional[int] = ..., wireless_mode_2ghz: _Optional[_Union[WifiConfig.WirelessMode, str]] = ..., apply_wireless_mode_2ghz: bool = ..., wireless_mode_5ghz: _Optional[_Union[WifiConfig.WirelessMode, str]] = ..., apply_wireless_mode_5ghz: bool = ..., wireless_mode_5ghz_high: _Optional[_Union[WifiConfig.WirelessMode, str]] = ..., apply_wireless_mode_5ghz_high: bool = ..., ht_bandwidth_2ghz: _Optional[_Union[WifiConfig.HTBandwidth, str]] = ..., apply_ht_bandwidth_2ghz: bool = ..., ht_bandwidth_5ghz: _Optional[_Union[WifiConfig.HTBandwidth, str]] = ..., apply_ht_bandwidth_5ghz: bool = ..., ht_bandwidth_5ghz_high: _Optional[_Union[WifiConfig.HTBandwidth, str]] = ..., apply_ht_bandwidth_5ghz_high: bool = ..., vht_bandwidth: _Optional[_Union[WifiConfig.VHTBandwidth, str]] = ..., apply_vht_bandwidth: bool = ..., vht_bandwidth_5ghz_high: _Optional[_Union[WifiConfig.VHTBandwidth, str]] = ..., apply_vht_bandwidth_5ghz_high: bool = ..., use_public_services: bool = ..., apply_use_public_services: bool = ..., disable_automated_speedtests: bool = ..., apply_disable_automated_speedtests: bool = ..., enable_umbilical_vlan: bool = ..., apply_enable_umbilical_vlan: bool = ..., client_names: _Optional[_Iterable[_Union[ClientName, _Mapping]]] = ..., apply_client_names: bool = ..., outdoor_mode: bool = ..., apply_outdoor_mode: bool = ..., disable_2ghz: bool = ..., apply_disable_2ghz: bool = ..., disable_5ghz: bool = ..., apply_disable_5ghz: bool = ..., disable_5ghz_high: bool = ..., apply_disable_5ghz_high: bool = ..., disable_x_mesh_backhaul: bool = ..., apply_disable_x_mesh_backhaul: bool = ..., golden_bssid: _Optional[str] = ..., apply_golden_bssid: bool = ..., golden_iface_type: _Optional[_Union[_wifi_util_pb2.IfaceType, str]] = ..., apply_golden_iface_type: bool = ..., tx_power_level_2ghz: _Optional[_Union[_wifi_util_pb2.TxPowerLevel, str]] = ..., apply_tx_power_level_2ghz: bool = ..., tx_power_level_5ghz: _Optional[_Union[_wifi_util_pb2.TxPowerLevel, str]] = ..., apply_tx_power_level_5ghz: bool = ..., tx_power_level_5ghz_high: _Optional[_Union[_wifi_util_pb2.TxPowerLevel, str]] = ..., apply_tx_power_level_5ghz_high: bool = ..., disable_pending_update_reboot: bool = ..., apply_disable_pending_update_reboot: bool = ..., client_configs: _Optional[_Iterable[_Union[ClientConfig, _Mapping]]] = ..., apply_client_configs: bool = ..., disable_set_wifi_config_from_controller: bool = ..., apply_disable_set_wifi_config_from_controller: bool = ..., client_key: _Optional[bytes] = ..., apply_client_key: bool = ..., wan_no_traffic_control: _Optional[_Union[NoTrafficControl, _Mapping]] = ..., wan_ack_suppression: _Optional[_Union[AckSuppression, _Mapping]] = ..., wan_cake_rate_limit: _Optional[_Union[CakeRateLimit, _Mapping]] = ..., apply_wan_traffic_control: bool = ..., wan_host_dscp_mark: _Optional[int] = ..., apply_wan_host_dscp_mark: bool = ..., debug_pop_pings: bool = ..., apply_debug_pop_pings: bool = ..., client_tester: bool = ..., apply_client_tester: bool = ..., tag: _Optional[int] = ...) -> None: ...

class WeeklyBlockSchedule(_message.Message):
    __slots__ = ("block_ranges", "group_id")
    class BlockRange(_message.Message):
        __slots__ = ("start_minutes", "end_minutes")
        START_MINUTES_FIELD_NUMBER: _ClassVar[int]
        END_MINUTES_FIELD_NUMBER: _ClassVar[int]
        start_minutes: int
        end_minutes: int
        def __init__(self, start_minutes: _Optional[int] = ..., end_minutes: _Optional[int] = ...) -> None: ...
    BLOCK_RANGES_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    block_ranges: _containers.RepeatedCompositeFieldContainer[WeeklyBlockSchedule.BlockRange]
    group_id: str
    def __init__(self, block_ranges: _Optional[_Iterable[_Union[WeeklyBlockSchedule.BlockRange, _Mapping]]] = ..., group_id: _Optional[str] = ...) -> None: ...

class ClientConfig(_message.Message):
    __slots__ = ("client_id", "mac_address", "given_name", "weekly_block_schedules", "group_id")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    MAC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    GIVEN_NAME_FIELD_NUMBER: _ClassVar[int]
    WEEKLY_BLOCK_SCHEDULES_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: int
    mac_address: str
    given_name: str
    weekly_block_schedules: _containers.RepeatedCompositeFieldContainer[WeeklyBlockSchedule]
    group_id: str
    def __init__(self, client_id: _Optional[int] = ..., mac_address: _Optional[str] = ..., given_name: _Optional[str] = ..., weekly_block_schedules: _Optional[_Iterable[_Union[WeeklyBlockSchedule, _Mapping]]] = ..., group_id: _Optional[str] = ...) -> None: ...

class ClientName(_message.Message):
    __slots__ = ("mac_address", "given_name")
    MAC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    GIVEN_NAME_FIELD_NUMBER: _ClassVar[int]
    mac_address: str
    given_name: str
    def __init__(self, mac_address: _Optional[str] = ..., given_name: _Optional[str] = ...) -> None: ...

class AuthOpen(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AuthWpa2(_message.Message):
    __slots__ = ("password",)
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    password: str
    def __init__(self, password: _Optional[str] = ...) -> None: ...

class AuthWpa3(_message.Message):
    __slots__ = ("password",)
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    password: str
    def __init__(self, password: _Optional[str] = ...) -> None: ...

class AuthWpa2Wpa3(_message.Message):
    __slots__ = ("password",)
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    password: str
    def __init__(self, password: _Optional[str] = ...) -> None: ...

class AuthRadius(_message.Message):
    __slots__ = ("server", "server_ca", "server_ca_base_64", "password", "transport")
    SERVER_FIELD_NUMBER: _ClassVar[int]
    SERVER_CA_FIELD_NUMBER: _ClassVar[int]
    SERVER_CA_BASE_64_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    TRANSPORT_FIELD_NUMBER: _ClassVar[int]
    server: str
    server_ca: str
    server_ca_base_64: str
    password: str
    transport: _wifi_util_pb2.Protocol
    def __init__(self, server: _Optional[str] = ..., server_ca: _Optional[str] = ..., server_ca_base_64: _Optional[str] = ..., password: _Optional[str] = ..., transport: _Optional[_Union[_wifi_util_pb2.Protocol, str]] = ...) -> None: ...

class NoTrafficControl(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AckSuppression(_message.Message):
    __slots__ = ("ack_mark", "htb_ack_queue_rate", "htb_ack_queue_ceil", "cake_queue_bandwidth", "cake_ack_filter_aggressive", "cake_manual_rtt")
    ACK_MARK_FIELD_NUMBER: _ClassVar[int]
    HTB_ACK_QUEUE_RATE_FIELD_NUMBER: _ClassVar[int]
    HTB_ACK_QUEUE_CEIL_FIELD_NUMBER: _ClassVar[int]
    CAKE_QUEUE_BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    CAKE_ACK_FILTER_AGGRESSIVE_FIELD_NUMBER: _ClassVar[int]
    CAKE_MANUAL_RTT_FIELD_NUMBER: _ClassVar[int]
    ack_mark: int
    htb_ack_queue_rate: float
    htb_ack_queue_ceil: float
    cake_queue_bandwidth: float
    cake_ack_filter_aggressive: bool
    cake_manual_rtt: float
    def __init__(self, ack_mark: _Optional[int] = ..., htb_ack_queue_rate: _Optional[float] = ..., htb_ack_queue_ceil: _Optional[float] = ..., cake_queue_bandwidth: _Optional[float] = ..., cake_ack_filter_aggressive: bool = ..., cake_manual_rtt: _Optional[float] = ...) -> None: ...

class CakeRateLimit(_message.Message):
    __slots__ = ("host_mark", "bandwidth", "priority_queue_parameter", "ack_filter", "manual_rtt")
    HOST_MARK_FIELD_NUMBER: _ClassVar[int]
    BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_QUEUE_PARAMETER_FIELD_NUMBER: _ClassVar[int]
    ACK_FILTER_FIELD_NUMBER: _ClassVar[int]
    MANUAL_RTT_FIELD_NUMBER: _ClassVar[int]
    host_mark: int
    bandwidth: float
    priority_queue_parameter: CakePriorityQueueParameter
    ack_filter: CakeAckFilter
    manual_rtt: float
    def __init__(self, host_mark: _Optional[int] = ..., bandwidth: _Optional[float] = ..., priority_queue_parameter: _Optional[_Union[CakePriorityQueueParameter, str]] = ..., ack_filter: _Optional[_Union[CakeAckFilter, str]] = ..., manual_rtt: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/command.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fspacex/api/device/command.proto\x12\x11SpaceX.API.Device\"\x91\x01\n\tPublicKey\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x45\n\x0c\x63\x61pabilities\x18\x02 \x03(\x0e\x32\x1d.SpaceX.API.Device.CapabilityB\x02\x18\x01R\x0c\x63\x61pabilities\x12+\n\x04user\x18\x03 \x01(\x0e\x32\x17.SpaceX.API.Device.UserR\x04user*\xd5\x01\n\nCapability\x12\x08\n\x04READ\x10\x00\x12\x11\n\rREAD_INTERNAL\x10\r\x12\x10\n\x0cREAD_PRIVATE\x10\x07\x12\t\n\x05LOCAL\x10\x0e\x12\t\n\x05WRITE\x10\x01\x12\x14\n\x10WRITE_PERSISTENT\x10\x0b\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\x12\t\n\x05SETUP\x10\x04\x12\x0b\n\x07SET_SKU\x10\x05\x12\x0b\n\x07REFRESH\x10\x06\x12\x08\n\x04\x46USE\x10\x08\x12\t\n\x05RESET\x10\t\x12\x08\n\x04TEST\x10\n\x12\x07\n\x03SSH\x10\x0c\x12\t\n\x05GUEST\x10\x0f*r\n\x04User\x12\x0b\n\x07NO_USER\x10\x00\x12\x07\n\x03GOD\x10\x01\x12\x07\n\x03LAN\x10\x02\x12\t\n\x05\x43LOUD\x10\x03\x12\x0b\n\x07\x46\x41\x43TORY\x10\x04\x12\n\n\x06ROUTER\x10\x05\x12\r\n\tGUEST_LAN\x10\x06\x12\x18\n\x14SENSITIVE_COMMANDING\x10\x07\x42\xd6\x01\n\x15\x63om.SpaceX.API.DeviceB\x0c\x43ommandProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\014CommandProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_PUBLICKEY'].fields_by_name['capabilities']._loaded_options = None
  _globals['_PUBLICKEY'].fields_by_name['capabilities']._serialized_options = b'\030\001'
  _globals['_CAPABILITY']._serialized_start=203
  _globals['_CAPABILITY']._serialized_end=416
  _globals['_USER']._serialized_start=418
  _globals['_USER']._serialized_end=532
  _globals['_PUBLICKEY']._serialized_start=55
  _globals['_PUBLICKEY']._serialized_end=200
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class UtDisablementCode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN_STATE: _ClassVar[UtDisablementCode]
    OKAY: _ClassVar[UtDisablementCode]
    NO_ACTIVE_ACCOUNT: _ClassVar[UtDisablementCode]
    TOO_FAR_FROM_SERVICE_ADDRESS: _ClassVar[UtDisablementCode]
    IN_OCEAN: _ClassVar[UtDisablementCode]
    INVALID_COUNTRY: _ClassVar[UtDisablementCode]
    BLOCKED_COUNTRY: _ClassVar[UtDisablementCode]
    DATA_OVERAGE_SANDBOX_POLICY: _ClassVar[UtDisablementCode]
    CELL_IS_DISABLED: _ClassVar[UtDisablementCode]
    UNLICENSED_COUNTRY: _ClassVar[UtDisablementCode]
UNKNOWN_STATE: UtDisablementCode
OKAY: UtDisablementCode
NO_ACTIVE_ACCOUNT: UtDisablementCode
TOO_FAR_FROM_SERVICE_ADDRESS: UtDisablementCode
IN_OCEAN: UtDisablementCode
INVALID_COUNTRY: UtDisablementCode
BLOCKED_COUNTRY: UtDisablementCode
DATA_OVERAGE_SANDBOX_POLICY: UtDisablementCode
CELL_IS_DISABLED: UtDisablementCode
UNLICENSED_COUNTRY: UtDisablementCode
